@@ -12,7 +12,7 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::Twitter;
 BEGIN {
-  $Dist::Zilla::Plugin::Twitter::VERSION = '0.001';
+  $Dist::Zilla::Plugin::Twitter::VERSION = '0.002';
 }
 # ABSTRACT: Twitter when you release with Dist::Zilla
 
@@ -35,7 +35,7 @@ has 'tweet' => (
 has 'tweet_url' => (
   is  => 'ro',
   isa => 'Str',
-  default => 'http://frepan.64p.org/~{{$AUTHOR}}/{{$TARBALL}}'
+  default => 'http://cpan.cpantesters.org/authors/id/{{$AUTHOR_PATH}}/{{$DIST}}-{{$VERSION}}.readme',
 );
 
 
@@ -49,18 +49,22 @@ sub after_release {
     my $cpan_id = '';
     for my $plugin ( @{ $zilla->plugins_with( -Releaser ) } ) {
       if ( my $user = eval { $plugin->user } ) {
-        $cpan_id = $user;
+        $cpan_id = uc $user;
         last;
       }
     }
     confess "Can't determine your CPAN user id from a release plugin"
       unless length $cpan_id;
 
+    my $path = substr($cpan_id,0,1)."/".substr($cpan_id,0,2)."/$cpan_id";
+
     my $stash = {
       DIST => $zilla->name,
       VERSION => $zilla->version,
       TARBALL => "$tgz",
-      AUTHOR => lc $cpan_id,
+      AUTHOR_UC => $cpan_id,
+      AUTHOR_LC => lc $cpan_id,
+      AUTHOR_PATH => $path,
     };
 
     my $longurl = $self->fill_in_string($self->tweet_url, $stash);
@@ -94,7 +98,7 @@ Dist::Zilla::Plugin::Twitter - Twitter when you release with Dist::Zilla
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -110,13 +114,15 @@ In your C<<< .netrc >>>:
 
 =head1 DESCRIPTION
 
-This plugin will use L<Net::Twitter> with the login and password in
-your C<<< .netrc >>> file to send a release notice to Twitter.
+This plugin will use L<Net::Twitter> with the login and password in your
+C<<< .netrc >>> file to send a release notice to Twitter.  By default, it will include
+a link to your README file as extracted on a fast CPAN mirror.  This works
+very nicely with L<Dist::Zilla::Plugin::ReadmeFromPod>.
 
 The default configuration is as follows:
 
    [Twitter]
-   tweet_url = http://frepan.64p.org/~{{$AUTHOR}}/{{$TARBALL}}
+   tweet_url = http://cpan.cpantesters.org/authors/id/{{$AUTHOR_PATH}}/{{$DIST}}-{{$VERSION}}.readme
    tweet = Released {{$DIST}}-{{$VERSION}} {{$URL}}
 
 The C<<< tweet_url >>> is shortened with L<WWW::Shorten::TinyURL> and
@@ -126,7 +132,9 @@ available for substitution in the URL and message templates:
        DIST        # Foo-Bar
        VERSION     # 1.23
        TARBALL     # Foo-Bar-1.23.tar.gz
-       AUTHOR      # CPAN author ID (in lower case)
+       AUTHOR_UC   # JOHNDOE
+       AUTHOR_LC   # johndoe
+       AUTHOR_PATH # J/JO/JOHNDOE
        URL         # TinyURL
 
 You must be using the C<<< UploadToCPAN >>> plugin for this plugin to
